@@ -1,7 +1,7 @@
-#' Hypergemoetric test
+#' Hypergeometric test
 #'
 #' Perform a hypergeometric test, also known as the Fisher's exact test, on a 2x2 contingency
-#' table with the alternative hypothesis 'greater' . In this application, the test finds the
+#' table with the alternative hypothesis set to 'greater'. In this application, the test finds the
 #' probability that counts[1, 1] or more genes would be found to be annotated to a term (pathway),
 #' assuming the null hypothesis of genes being distributed randomly to terms. 
 #'
@@ -28,12 +28,12 @@ hypergeometric <- function(counts) {
 #'
 #' @param genelist Character vector of gene names, assumed to be ordered by decreasing importance. 
 #' For example, the genes could be ranked by decreasing significance of differential expression. 
-#' @param background Character vector of gene names. List of all genes used as a statistical background (i.e., the universe)
+#' @param background Character vector of gene names. List of all genes used as a statistical background (i.e., the universe).
 #' @param annotations Character vector of gene names. A gene set representing a functional term, process or biological pathway. 
 #'
 #' @return a list with the items:
 #'   \describe{
-#'     \item{p.val}{The lowest obtained p-value}
+#'     \item{p_val}{The lowest obtained p-value}
 #'     \item{ind}{The index of \code{genelist} such that \code{genelist[1:ind]}
 #'       gives the lowest p-value}
 #'  }
@@ -45,11 +45,11 @@ hypergeometric <- function(counts) {
 orderedHypergeometric <- function(genelist, background, annotations) {
     # Only test subsets of genelist that end with a gene in annotations since
     # these are the only tests for which the p-value can decrease
-    which.in <- which(genelist %in% annotations)
-    if (length(which.in) == 0) return(list(p.val=1, ind=1))
+    which_in <- which(genelist %in% annotations)
+    if (length(which_in) == 0) return(list(p_val=1, ind=1))
 
-    # Construct the counts matrix for the first which.in[1] genes
-    gl <- genelist[1:which.in[1]]
+    # Construct the counts matrix for the first which_in[1] genes
+    gl <- genelist[1:which_in[1]]
     cl <- setdiff(background, gl)
     genelist0 <- length(gl) - 1
     complement1 <- length(which(cl %in% annotations))
@@ -57,15 +57,15 @@ orderedHypergeometric <- function(genelist, background, annotations) {
     counts <- matrix(data=c(1, genelist0, complement1, complement0), nrow=2)
     scores <- hypergeometric(counts)
 
-    if (length(which.in) == 1) return(list(p.val=scores, ind=which.in[1]))
+    if (length(which_in) == 1) return(list(p_val=scores, ind=which_in[1]))
 
-    # Update counts and recalculate score for the rest of the indeces in which.in
-    # The genes in genelist[which.in[i]:which.in[i-1]] are added to the genes
+    # Update counts and recalculate score for the rest of the indeces in which_in
+    # The genes in genelist[which_in[i]:which_in[i-1]] are added to the genes
     # being tested and removed from the complement. Of these, 1 will always be
     # in annotations and the rest will not. Therefore we can just modify the
     # contingency table rather than recounting which genes are in annotations
-    for (i in 2:length(which.in)) {
-        diff <- which.in[i] - which.in[i-1]
+    for (i in 2:length(which_in)) {
+        diff <- which_in[i] - which_in[i-1]
         counts[1, 1] <- i
         counts[2, 1] <- counts[2, 1] + diff - 1
         counts[1, 2] <- counts[1, 2] - 1
@@ -74,10 +74,10 @@ orderedHypergeometric <- function(genelist, background, annotations) {
     }
 
     # Return the lowest p-value and the associated index
-    min.score <- min(scores)
+    min_score <- min(scores)
     
-    ind = which.in[max(which(scores==min.score))]
-    p.val = min.score
+    ind = which_in[max(which(scores==min_score))]
+    p_val = min_score
     
-	list(p.val=p.val, ind=ind)
+	list(p_val=p_val, ind=ind)
 }
